@@ -2,6 +2,11 @@
 # modified by Peter Langfelder to make it compaticle with R's standard hclust
 
 flashClust <- function(d, method="complete",  members = NULL)
+{
+  hclust(d, method, members)
+}
+
+hclust <- function(d, method="complete",  members = NULL)
 {
 
 # Hierarchical clustering, on raw input data; we will use Euclidean distance.
